#! /usr/bin/ruby
# encoding: utf-8

unless ARGV.length >= 1
  puts 'usage: ruby add-color-to-srt.rb source.srt [desc.srt] [color]       # default color: ffea00'
  exit 1
end

def main(source_path, dest_path, color)
  contents = File.read(source_path)
  # File.write(dest_path, add_color(contents, color))
  # because OS X uses ruby 1.8.7, we have to use this form:
  out_file = File.new(dest_path, 'w')
  out_file.write(add_color(contents, color))
end

def add_color(lines, color)
  result = ''
  next_line_is_timestamp = false
  next_line_is_subtitle = false
  
  lines.lines.each do |line|
    line.chomp!

    if line =~ /^[[:blank:]]*$/         # read a new lines
      result += "\r\n"
      next_line_is_subtitle = false
    end

    if next_line_is_timestamp           # now we're on timestamp line
      result += "#{line}\r\n"
      next_line_is_timestamp = false
      next_line_is_subtitle = true
    elsif next_line_is_subtitle         # now we're on actual subtitle line(s)
      result += "<font color='##{color}'>#{line}</font>\r\n"
    end

    if line =~ /^[[:digit:]]+$/         # read line id
      next_line_is_timestamp = true
      next_line_is_subtitle = false
      result += "#{line}\r\n"
    end
  end

  result
end

color = ARGV[2] || 'ffea00'
dest_path = ARGV[1] || (ARGV[0].sub /\.srt$/, '-color.srt')
main ARGV[0], dest_path, color